==> ejc-scientific-impl-3.0.0-20250306.080245-36-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectBudgetEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-经费预算
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_budget")
public class SciProjectBudgetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="fee_id")
    private Long feeId; // 费用类型主键
    @TableField(value="fee_name")
    private String feeName; // 费用类型名称
    @TableField(value="budget_mny")
    private BigDecimal budgetMny; // 预算金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getFeeId() {
        return feeId;
    }

    public void setFeeId(Long feeId) {
        this.feeId = feeId;
    }
    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-scientific-impl-3.0.0-20250829.061142-90-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectBudgetEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-经费预算
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_budget")
public class SciProjectBudgetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="fee_id")
    private Long feeId; // 费用类型主键
    @TableField(value="fee_name")
    private String feeName; // 费用类型名称
    @TableField(value="budget_mny")
    private BigDecimal budgetMny; // 预算金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源主键

    @TableField(exist=false)
    @SubEntity(serviceName="sciProjectBudgetYearService")//此处有pid="xxx"，默认值pid="pid"
    private List<SciProjectBudgetYearEntity> yearList = new ArrayList<>(); // 科研项目立项-经费预算-年度预算
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getFeeId() {
        return feeId;
    }

    public void setFeeId(Long feeId) {
        this.feeId = feeId;
    }
    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public List<SciProjectBudgetYearEntity> getYearList() {
        return yearList;
    }

    public void setYearList(List<SciProjectBudgetYearEntity> yearList) {
        this.yearList = yearList;
    }
}
